Crate pylon_storage

Crate pylon_storage 

Modules

files
Pluggable file storage abstraction.
pool
postgres
search
Native faceted full-text search for Pylon entities.
search_maintenance
FTS5 + facet bitmap maintenance on insert / update / delete.
search_query
Query planner for faceted full-text search.
sqlite

Structs

ColumnSnapshot
DiffAdapter
A storage adapter that plans the transition from an old manifest to a new one.
DryRunAdapter
A storage adapter that assumes no existing schema. It produces a plan to create everything from scratch.
FieldSpec
IndexSnapshot
PlanAnalysis
PlanWarning
SchemaPlan
SchemaSnapshot
StorageError
TableSnapshot

Enums

SchemaOperation

Traits

StorageAdapter

Functions

analyze_plan
Analyze a schema plan for destructive or unsupported operations.
plan_from_snapshot
Plan additive schema changes from a snapshot to a target manifest. Shared by both SQLite and Postgres adapters. Only produces CreateEntity, AddField, AddIndex, and Noop.