Module pool

Module pool 

Structs

ConnectionPool
A minimal database connection pool.
PooledConnection
RAII guard that returns the connection to the pool on drop.

Enums

PoolError
Error returned when a connection cannot be acquired from the pool.