pub struct DiffAdapter {
pub from: AppManifest,
}Expand description
A storage adapter that plans the transition from an old manifest to a new one.
Fields
from: AppManifestTrait Implementations
Sourceimpl StorageAdapter for DiffAdapter
impl StorageAdapter for DiffAdapter
Sourcefn plan_schema(&self, target: &AppManifest) -> Result<SchemaPlan, StorageError>
fn plan_schema(&self, target: &AppManifest) -> Result<SchemaPlan, StorageError>
Produce a plan that would bring storage in line with the target manifest.
Sourcefn apply_schema(&self, _plan: &SchemaPlan) -> Result<(), StorageError>
fn apply_schema(&self, _plan: &SchemaPlan) -> Result<(), StorageError>
Apply a schema plan. Not implemented by dry-run adapters.