Modules
- files
- Pluggable file storage abstraction.
- pool
- postgres
- search
- Native faceted full-text search for Pylon entities.
- search_
maintenance - FTS5 + facet bitmap maintenance on insert / update / delete.
- search_
query - Query planner for faceted full-text search.
- sqlite
Structs
- Column
Snapshot - Diff
Adapter - A storage adapter that plans the transition from an old manifest to a new one.
- DryRun
Adapter - A storage adapter that assumes no existing schema. It produces a plan to create everything from scratch.
- Field
Spec - Index
Snapshot - Plan
Analysis - Plan
Warning - Schema
Plan - Schema
Snapshot - Storage
Error - Table
Snapshot
Enums
Traits
Functions
- analyze_
plan - Analyze a schema plan for destructive or unsupported operations.
- plan_
from_ snapshot - Plan additive schema changes from a snapshot to a target manifest. Shared by both SQLite and Postgres adapters. Only produces CreateEntity, AddField, AddIndex, and Noop.